/*
 *  Twidere X
 *
 *  Copyright (C) 2020-2021 Tlaster <tlaster@outlook.com>
 * 
 *  This file is part of Twidere X.
 * 
 *  Twidere X is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  Twidere X is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Twidere X. If not, see <http://www.gnu.org/licenses/>.
 */
package com.twidere.twiderex.worker.draft

import android.content.Context
import androidx.hilt.Assisted
import androidx.hilt.work.WorkerInject
import androidx.work.CoroutineWorker
import androidx.work.OneTimeWorkRequestBuilder
import androidx.work.WorkerParameters
import com.twidere.twiderex.model.ComposeData
import com.twidere.twiderex.model.toComposeData
import com.twidere.twiderex.model.toWorkData
import com.twidere.twiderex.notification.InAppNotification
import com.twidere.twiderex.repository.DraftRepository
import com.twidere.twiderex.utils.notify

class SaveDraftWorker @WorkerInject constructor(
    @Assisted context: Context,
    @Assisted workerParams: WorkerParameters,
    private val repository: DraftRepository,
    private val inAppNotification: InAppNotification,
) : CoroutineWorker(context, workerParams) {

    companion object {
        fun create(data: ComposeData) = OneTimeWorkRequestBuilder<SaveDraftWorker>()
            .setInputData(data.toWorkData())
            .build()
    }

    override suspend fun doWork(): Result {
        val data = inputData.toComposeData()
        with(data) {
            return try {
                repository.addOrUpgrade(
                    content,
                    images,
                    composeType = composeType,
                    statusKey = statusKey,
                    draftId = draftId,
                    excludedReplyUserIds = excludedReplyUserIds,
                )
                Result.success()
            } catch (e: Throwable) {
                e.notify(inAppNotification)
                Result.failure()
            }
        }
    }
}
